@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "devicesmodel.h"
@@ -24,12 +24,12 @@
 #include <KLocalizedString>
 
 #include <QString>
-#include <QDBusInterface>
 #include <QDBusPendingReply>
 #include <QIcon>
 #include <QDBusServiceWatcher>
 
 #include "dbusinterfaces.h"
+#include <dbushelper.h>
 // #include "modeltest.h"
 
 Q_LOGGING_CATEGORY(KDECONNECT_INTERFACES, "kdeconnect.interfaces");
@@ -59,7 +59,7 @@ DevicesModel::DevicesModel(QObject* parent)
             this, &DevicesModel::deviceRemoved);
 
     QDBusServiceWatcher* watcher = new QDBusServiceWatcher(DaemonDbusInterface::activatedService(),
-                                                           QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
+                                                           DBusHelper::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
     connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, &DevicesModel::refreshDeviceList);
     connect(watcher, &QDBusServiceWatcher::serviceUnregistered, this, &DevicesModel::clearDevices);
 
