@@ -15,42 +15,57 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "notification.h"
 #include "notification_debug.h"
 
 #include <KNotification>
+#include <QtGlobal>
 #include <QIcon>
 #include <QString>
 #include <QUrl>
 #include <QPixmap>
 #include <KLocalizedString>
 #include <QFile>
+#include <knotifications_version.h>
+#include <QJsonArray>
 
 #include <core/filetransferjob.h>
+#include <core/notificationserverinfo.h>
 
 QMap<QString, FileTransferJob*> Notification::s_downloadsInProgress;
 
-Notification::Notification(const NetworkPacket& np, QObject* parent)
+Notification::Notification(const NetworkPacket& np, const Device* device, QObject* parent)
     : QObject(parent)
+    , m_imagesDir()
+    , m_device(device)
 {
-    //Make a own directory for each user so noone can see each others icons
+    //Make a own directory for each user so no one can see each others icons
     QString username;
     #ifdef Q_OS_WIN
-        username = qgetenv("USERNAME");
+        username = QString::fromLatin1(qgetenv("USERNAME"));
     #else
-        username = qgetenv("USER");
+        username = QString::fromLatin1(qgetenv("USER"));
     #endif
 
-    m_imagesDir = QDir::temp().absoluteFilePath(QStringLiteral("kdeconnect_") + username);
+    m_imagesDir.setPath(QDir::temp().absoluteFilePath(QStringLiteral("kdeconnect_") + username));
     m_imagesDir.mkpath(m_imagesDir.absolutePath());
     QFile(m_imagesDir.absolutePath()).setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ExeOwner);
     m_ready = false;
 
     parseNetworkPacket(np);
     createKNotification(np);
+
+    connect(m_notification, QOverload<unsigned int>::of(&KNotification::activated), this, [this] (unsigned int actionIndex) {
+        // Do nothing for our own reply action
+        if(!m_requestReplyId.isEmpty() && actionIndex == 1) {
+            return;
+        }
+        // Notification action indices start at 1
+        Q_EMIT actionTriggered(m_internalId, m_actions[actionIndex - 1]);
+    });
 }
 
 Notification::~Notification()
@@ -79,7 +94,7 @@ void Notification::update(const NetworkPacket& np)
     createKNotification(np);
 }
 
-KNotification* Notification::createKNotification(const NetworkPacket& np)
+void Notification::createKNotification(const NetworkPacket& np)
 {
     if (!m_notification) {
         m_notification = new KNotification(QStringLiteral("notification"), KNotification::CloseOnTimeout, this);
@@ -90,20 +105,33 @@ KNotification* Notification::createKNotification(const NetworkPacket& np)
     QString escapedText = m_text.toHtmlEscaped();
     QString escapedTicker = m_ticker.toHtmlEscaped();
 
-    m_notification->setTitle(m_appName.toHtmlEscaped());
-
-    if (m_title.isEmpty() && m_text.isEmpty()) {
-       m_notification->setText(escapedTicker);
-    } else if (m_appName==m_title) {
+#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 57, 0)
+    if (NotificationServerInfo::instance().supportedHints().testFlag(NotificationServerInfo::X_KDE_DISPLAY_APPNAME)) {
+        m_notification->setTitle(escapedTitle);
         m_notification->setText(escapedText);
-    } else if (m_title.isEmpty()){
-         m_notification->setText(escapedText);
-    } else if (m_text.isEmpty()){
-         m_notification->setText(escapedTitle);
+        m_notification->setHint(QStringLiteral("x-kde-display-appname"), m_appName.toHtmlEscaped());
     } else {
-        m_notification->setText(escapedTitle+": "+escapedText);
+#endif
+        m_notification->setTitle(m_appName.toHtmlEscaped());
+
+        if (m_title.isEmpty() && m_text.isEmpty()) {
+            m_notification->setText(escapedTicker);
+        } else if (m_appName == m_title) {
+            m_notification->setText(escapedText);
+        } else if (m_title.isEmpty()) {
+            m_notification->setText(escapedText);
+        } else if (m_text.isEmpty()) {
+            m_notification->setText(escapedTitle);
+        } else {
+            m_notification->setText(escapedTitle + QStringLiteral(": ") + escapedText);
+        }
+
+#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 57, 0)
     }
 
+    m_notification->setHint(QStringLiteral("x-kde-origin-name"), m_device->name());
+#endif
+
     m_hasIcon = m_hasIcon && !m_payloadHash.isEmpty();
 
     if (!m_hasIcon) {
@@ -115,11 +143,11 @@ KNotification* Notification::createKNotification(const NetworkPacket& np)
     }
 
     if (!m_requestReplyId.isEmpty()) {
-        m_notification->setActions(QStringList(i18n("Reply")));
+        m_actions.prepend(i18n("Reply"));
         connect(m_notification, &KNotification::action1Activated, this, &Notification::reply, Qt::UniqueConnection);
     }
 
-    return m_notification;
+    m_notification->setActions(m_actions);
 }
 
 void Notification::loadIcon(const NetworkPacket& np)
@@ -158,7 +186,7 @@ void Notification::applyIcon()
 
 void Notification::applyNoIcon()
 {
-    //HACK The only way to display no icon at all is trying to load a non-existant icon
+    //HACK The only way to display no icon at all is trying to load a non-existent icon
     m_notification->setIconName(QStringLiteral("not_a_real_icon"));
 }
 
@@ -179,4 +207,12 @@ void Notification::parseNetworkPacket(const NetworkPacket& np)
     m_silent = np.get<bool>(QStringLiteral("silent"));
     m_payloadHash = np.get<QString>(QStringLiteral("payloadHash"));
     m_requestReplyId = np.get<QString>(QStringLiteral("requestReplyId"), QString());
+
+    m_actions.clear();
+
+    const auto actions = np.get<QJsonArray>(QStringLiteral("actions"));
+    for (const QJsonValue& value : actions) {
+        m_actions.append(value.toString());
+    }
+
 }
