@@ -15,18 +15,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef NOTIFICATIONSPLUGIN_H
 #define NOTIFICATIONSPLUGIN_H
 
-#include <knotification.h>
-
 #include <core/kdeconnectplugin.h>
 
-#define PACKAGE_TYPE_NOTIFICATION_REQUEST QStringLiteral("kdeconnect.notification.request")
-#define PACKAGE_TYPE_NOTIFICATION_REPLY QStringLiteral("kdeconnect.notification.reply")
+#define PACKET_TYPE_NOTIFICATION_REQUEST QStringLiteral("kdeconnect.notification.request")
+#define PACKET_TYPE_NOTIFICATION_REPLY QStringLiteral("kdeconnect.notification.reply")
+#define PACKET_TYPE_NOTIFICATION_ACTION QStringLiteral("kdeconnect.notification.action")
+
 
 /*
  * This class is just a proxy for NotificationsDbusInterface
@@ -34,7 +34,6 @@
  * KdeConnectPlugin at the same time (both are QObject)
  */
 class NotificationsDbusInterface;
-class NotificationsListener;
 
 class NotificationsPlugin
     : public KdeConnectPlugin
@@ -44,14 +43,12 @@ class NotificationsPlugin
 public:
     explicit NotificationsPlugin(QObject* parent, const QVariantList& args);
     ~NotificationsPlugin() override;
-    
-    bool receivePackage(const NetworkPackage& np) override;
+
+    bool receivePacket(const NetworkPacket& np) override;
     void connected() override;
 
 protected:
     NotificationsDbusInterface* notificationsDbusInterface;
-    NotificationsListener* notificationsListener;
-
 };
 
 #endif
